:
#
#       Copyright (C) 1989 The Santa Cruz Operation Inc. All Rights Reserved
#       This Module contains Proprietary Information of
#       The Santa Cruz Operation Inc, and should be treated as Confidential.
#

#BEGIN_CM_SCRIPTLIB
#
# Standard CM script function library
# baselib v1.2
#

PATH=/bin:/usr/bin:/etc:.
LANG=english_us.ascii	# Used when scripts are internationalized.
export PATH LANG

TMPFILE=/tmp/tmp$$    # Define a temporary file for use if necessary.
TMPFILE1=/tmp/tmp1$$    # Define a temporary file for use if necessary.
TMPFILE2=/tmp/tmp2$$    # Define a temporary file for use if necessary.

# Define return values.
: ${OK=0} ${FAIL=1} ${STOP=10}
 
#
# Print an error message.
#
error() {
	echo "\nError: $*" >&2
	return 0
}
 
#
# usage: safemv file1 file2
# move file1 to file2 without chance of interruption
#
safemv() {
	trap "" 1 2 3 15
	mv $1 $2
	trap 1 2 3 15
	return 0
}
 
#
# SHOULD BE USED WITH EVERY INSTALLATION SCRIPT
#
# Set the variable $prdperm to  /etc/perms/$PRDVALUE or ./tmp/perms/$PRDVALUE
# If the permlist is found, the values for set, prd, ver, typ, rel,
# and upd are set from the permlist.
# Also determine the OS type, xenix or unix, and set systype accordingly.
#
# sets following information in exported variables
# OSREL: x.x.xy	OSTYPE: unix|xenix	OSBUS: isa|mc|ambi
# OSPRD: <prd value>	OSMCH: <os machine type>
# echo "OS Release: $OSREL	OS Type: $OSTYPE	OS Bus: $OSBUS"
# echo "OS PRD Value: $OSPRD	OS Machine Type: $OSMCH"
#
SETVARS1="Permlist not found"
SETVARS2="Failed to set values from"
SETVARS3="Incorrect prd value in"

# Variables set by setvars.
prdperm=
fixperm=fixperm
brand=brand
set=
prd=
typ=
rel=
ser=
upd=
systype=unknown

setvars() {

# Locate fixperm, brand, and the permlist.
	for _i in /etc ./tmp
	do
	    [ -f "$_i/fixperm" ] && fixperm=$_i/fixperm
	    [ -f "$_i/brand" ] && brand=$_i/brand
	    [ -f "$_i/perms/$PRDVALUE" ] && prdperm=$_i/perms/$PRDVALUE
	done

	[ "$prdperm" ] || {
		echo "Warning: $PRDVALUE $SETVARS1" >&2
		return 1
	}

# Get the operating system type:
	case `uname -r` in
		2.*)	systype=xenix
			;;
		3.*)	systype=unix
			;;
		*)	systype=unknown
			;;
	esac

#
# OS variables setting
# OSREL: x.x.xy		OSTYPE: unix|xenix	OSBUS: isa|mc|ambi
# OSPRD: <prdvalue>	OSMCH: os mch type
#
	OSTYPE=$systype
	case "$OSTYPE" in
	    unix)
		eval `sed -n '/^#prd=/s/#//p
			/^#typ=/s/#//p
			/^#rel=/s/#//p' /etc/perms/rtsmd` > /dev/null 2>&1
		OSREL=$rel
		OSPRD=$prd
		OSMCH=$typ
		# Systems 3.2.3 and later are ambi-architectural,
		# ie. will work on either mc or isa.
		case "$OSREL" in
		    3.2.[012]*)
			if [ -r /dev/mcapos ]
			then
			    if grep mcapos /etc/perms/rtsmd > /dev/null 2>&1
			    then
				OSBUS=mc
			    else
				OSBUS=unknown
			    fi
			else
			    OSBUS=isa
			fi
			;;
		    3.2.[3-9]*)
			OSBUS=ambi
			;;
		    *)
			OSBUS=unknown
			;;
		esac
		;;
	    xenix)
		eval `sed -n '/^#prd=/s/#//p
			/^#typ=/s/#//p
			/^#rel=/s/#//p' /etc/perms/inst` > /dev/null 2>&1
		OSREL=$rel
		OSPRD=$prd
		OSMCH=$typ
		var=`expr $OSMCH : '.*\(..\)$'`
		if [ "$var" = "MC" -o "$var" = "PS" ]
		then
			OSBUS=mc
		else
			OSBUS=isa
		fi
		;;
	    *)
		OSREL=unknown
		OSTYPE=unknown
		OSBUS=unknown
		OSPRD=unknown
		OSMCH=unknown
		;;
	esac

	export OSREL OSTYPE OSBUS OSPRD OSMCH
	# Clear these vars before they are used below.
	prd=
	rel=
	typ=
	
# Extract product info from the permlist.
	eval `sed -n '/^#set=/s/#//p
		/^#prd=/s/#//p
		/^#typ=/s/#//p
		/^#rel=/s/#//p
		/^#ser=/s/#//p
		/^#upd=/s/#//p' $prdperm` || echo "\n$SETVARS2 $prdperm" >&2

# Check the prd value read from the permlist for correctness.

	case "$prd" in
	    "$PRDVALUE")	return 0
				;;
		      *)	echo "\n$SETVARS3 $prdperm"  >&2
				return 1
				;;
	esac

	return 0
}
 
#
# Standard CM script function library
# configlib V1.0
# Contains: baselib, specificlib
#
 
#
# Standard CM script function library
# specificlib v1.4
# contains: baselib
#
 
#
# man_index: update the /usr/man/index file to include new 
# man page listings.
#
INDEXERR1="Failed to set up man page index."

man_index() {
   
   # If there is no index.OS but is an index (backwards compatability with
   #  old Unix man system) move the index (should be almost purely OS) into
   #  index.OS and have it treated as such.

   ixtmp=/tmp/$$

   if [ ! -f /usr/man/index.OS -a -f /usr/man/index ]
   then
	safemv /usr/man/index /usr/man/index.OS
   fi

   # cat all the man pages into one big index for use by man
   # ( remember to remove comments, backwards compatability-wise )
   # nb. grep -h ensures that filenames are not included in the output.

   [ -d /usr/man -a -f /usr/man/index.OS ] && {
	grep -vh "^#" /usr/man/index.* > $ixtmp.index 2> /dev/null

	sort -u $ixtmp.index > /usr/man/index || {
		error "$INDEXERR1"
		return 1
	}
	rm -f $ixtmp.index  2>/dev/null
   }
   return 0
}
 
#
# Remove the description of the man pages from the mandesc file.
# Usage: rmv_desc  <section>
#
RMVDESCERR1="Unable to edit /etc/default/man"

rmv_desc () {

    tmp=/tmp/$$
    SECT=$1
    [ "$SECT" ] || return 1

    [ -f /usr/man/mandesc ] && {
		# NB Whitespace between [ ] below is space _and_ TAB
	grep -vh "^cat.$SECT[ 	]" /usr/man/mandesc  > $tmp.dsc  2>/dev/null
	[ -s "$tmp.dsc" ] &&  cp  $tmp.dsc  /usr/man/mandesc
	rm -f $tmp.dsc
    }

# Remove the section name from the ORDER=... line in the /etc/default/man file
# Note that the sed regex. handles two cases separately: the first regex
# handles the case where $SECT is at the start or in the middle of the list.
# The second handles the case where $SECT is at the end of the line.

    [ -f ./etc/default/man ] && {
	if ( sed '/^ORDER=/s/\([:=]\)'$SECT':/\1/
		  /^ORDER=/s/:'$SECT'$//'  /etc/default/man  > $tmp.man )
	then
		cp  $tmp.man /etc/default/man
		rm -f $tmp.man
	else
		error "$RMVDESCERR1"
		return 1
	fi
    }

    return 0
}
 
#
# Remove man pages
# Usage: rmv_man_pages  section-name
#
rmv_man_pages () {
    SECTION=$1
    [ "$SECTION" ] || return 1

    # Remove the index file specific to this product
    [ -f "/usr/man/index.$SECTION" ]  &&  rm -f  /usr/man/index.$SECTION 

    # Remake the /usr/man/index file.
    man_index || return 1

    # Remove the description of the man pages from the mandesc file.
    rmv_desc  "$SECTION" || return 1

    return 0
}
 
#END_CM_SCRIPTLIB

#
# MAIN	
#

# PRD value for product, set to default if not previously set
PRDVALUE=${PRDVALUE-"scosmt"} ; export PRDVALUE

setvars

# assumes to be running at the
# root directory.
cd /

# Remove the section SMT information from the /usr/man directory.
rmv_man_pages  "SMT"  || exit $FAIL

exit 0
